@@ -4,8 +4,7 @@ from django.views.decorators.http import require_http_methods
 
 from django.contrib.auth.decorators import login_required
 
-from emailconfirmation.models import EmailAddress
-
+from account.models import EmailAddress
 from kaleo.forms import InviteForm
 from kaleo.models import JoinInvitation
 
